# dikicli

Commandline interface to diki.pl polish-english dictionary.

Dikicli allows you to use diki.pl from comfort of your terminal.
All results are cached for faster retrieval in the future.

## Usage:

Translate english to polish:

    diki word

Translate polish to engish:

    diki -p word

Display html file of all words translated so far:

    diki -i
